/*
DL2 Monitor: ./pa/portmap.h
Copyright (C) 2002, Rolf Jger, Ulm (Germany)

See the file README for information on usage and redistribution
of this source code file, and for a DISCLAIMER OF ALL WARRANTIES.
*/

/*----------------------------------------------------------------------------
 * Datalink Monitor (portmap): Port Mapping (local)
 * 
 * This port mapping assignes an acronym to well-known port numbers which
 * are usually appear in TCP/UDP frames. The range of supported port numbers
 * has been restricted to 0..255.
 * There are two objects of global scope, pa_portname and pa_port2idx. The
 * pa_portname object refers to some acronyms corresponding to port numbers,
 * the pa_port2idx maps a port number to an index with respect to the table
 * of acronyms. The PA_PORTNAME(pn) macro returns the acronym to port number
 * pn, if any has been assigned, 0 otherwise.
 * Requires invocation of dl2pa_libinit() prior to use of PA_PORTNAME(). 
 *
 * Author: Rolf Jger,Ulm
 *----------------------------------------------------------------------------
 * YYYYMMDD  History 
 * 20020414  created from scratch
 * $Id: portmap.h,v 1.1 2002/04/14 17:53:15 dv Exp $
 *----------------------------------------------------------------------------
*/
# ifndef __PORTMAP_H__
# define __PORTMAP_H__

# define PA_N_PORTNUMBERS 256
extern const unsigned char *dl2pa_port2idx;
extern const char *dl2pa_portname[];

# define PA_PORTNAME(pn) \
  ((pn) < PA_N_PORTNUMBERS ? dl2pa_portname[dl2pa_port2idx[(pn)]] : 0) 

# endif /*__PORTMAP_H__*/
